@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import tkinter as tk
 from typing import Any
 
@@ -8,9 +10,10 @@ class CustomText(tk.Text):
         super().__init__(*args, **kwargs)
 
         # Create a proxy for the underlying widget
-        self._orig = self._w + '_orig'
-        self.tk.call('rename', self._w, self._orig)
-        self.tk.createcommand(self._w, self._proxy)
+        widget_name = self._w  # type: ignore[attr-defined]
+        self._orig = widget_name + '_orig'
+        self.tk.call('rename', widget_name, self._orig)
+        self.tk.createcommand(widget_name, self._proxy)
 
     def _proxy(self, *args) -> Any:
         # Let the actual widget perform the requested action
@@ -19,7 +22,7 @@ class CustomText(tk.Text):
         try:
             result = self.tk.call(cmd)
         except tk.TclError:
-            return ''
+            result = ''
 
         # Generate an event if something was added or deleted,
         # or the cursor position changed.
